InventoryInterface class
Constructors
- InventoryInterface({String itemDescription = '', double price = 0.0, int quantity = 0})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemDescription → String
-
final
- price → double
-
final
- quantity → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited