POSResultInterface class

Constructors

POSResultInterface({Map<String, String> resultObject = const {}, String resultMessage = '', String resultCode = '', String deviceMessage = '', String deviceCode = '', String refNum = '', String cardType = '', String entryMode = '', String authCode = '', String maskedPAN = '', String batchNumber = '', String uti = '', String traceID = '', String mid = '', String tid = '', String authResponse = '', String authResponseCode = '', String rrn = '', String stan = '', String aid = '', String tvr = '', String tsi = '', String cvr = ''})
const

Properties

aid String
final
authCode String
final
authResponse String
final
authResponseCode String
final
batchNumber String
final
cardType String
final
cvr String
final
deviceCode String
final
deviceMessage String
final
entryMode String
final
hashCode int
The hash code for this object.
no setterinherited
maskedPAN String
final
mid String
final
refNum String
final
resultCode String
final
resultMessage String
final
resultObject Map<String, String>
final
rrn String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stan String
final
tid String
final
traceID String
final
tsi String
final
tvr String
final
uti String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited