PrintAddressInterface class

Constructors

PrintAddressInterface({String address1 = '', String address2 = '', String city = '', String state = '', String postalCode = '', String country = ''})
const

Properties

address1 String
final
address2 String
final
city String
final
country String
final
hashCode int
The hash code for this object.
no setterinherited
postalCode String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited