PrinterGateway class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cutPaper(
) → Future< Either< String, bool> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
print(
PrinterRequestInterface printerRequest) → Future< Either< String, POSResultInterface> > -
printBothCustomerAndMerchantCopy(
String referenceNumber) → Future< Either< String, POSResultInterface> > -
printCustomerCopy(
String referenceNumber) → Future< Either< String, POSResultInterface> > -
printMerchantCopy(
String referenceNumber) → Future< Either< String, POSResultInterface> > -
printRefund(
PrinterRequestInterface printerRequest) → Future< Either< String, POSResultInterface> > -
printString(
String printerRequest) → Future< Either< String, POSResultInterface> > -
reprint(
String referenceNumber) → Future< Either< String, POSResultInterface> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited