PrinterRequestInterface class

Constructors

PrinterRequestInterface({String transactionID = '', String id = '', String customerId = '', String customerName = '', String customerEmail = '', String customerMobile = '', bool displayCustomer = false, bool displaySeller = false, bool? displayAddress = false, bool? displayBusinessMobile = false, String ticketId = '', String ticketName = '', String sellerId = '', String sellerName = '', String currencyCode = '', String countryCode = '', String deviceId = '', bool taxInclusive = false, double totalValue = 0.0, double totalCost = 0.0, double totalMarkup = 0.0, double totalDiscount = 0.0, double totalTax = 0.0, double amountTendered = 0.0, double amountChange = 0.0, String transactionDate = '', String transactionTime = '', String businessName = '', PrintAddressInterface address = const PrintAddressInterface(), String vAT = '', String tell = '', String checkoutMessage = '', String taxCode = '', double taxValue = 0.0, List<InventoryInterface> items = const [], String header = '', String footer = '', String instagram = '', String website = '', String whatsapp = '', Uint8List? image, double? cashbackAmount, double? tipAmount, String? paymentType, double? totalDue, double? withdrawalAmount})
const

Properties

address PrintAddressInterface
final
amountChange double
final
amountTendered double
final
businessName String
final
cashbackAmount double?
final
checkoutMessage String
final
countryCode String
final
currencyCode String
final
customerEmail String
final
customerId String
final
customerMobile String
final
customerName String
final
deviceId String
final
displayAddress bool?
final
displayBusinessMobile bool?
final
displayCustomer bool
final
displaySeller bool
final
final
hashCode int
The hash code for this object.
no setterinherited
final
id String
final
image Uint8List?
final
instagram String
final
items List<InventoryInterface>
final
paymentType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sellerId String
final
sellerName String
final
taxCode String
final
taxInclusive bool
final
taxValue double
final
tell String
final
ticketId String
final
ticketName String
final
tipAmount double?
final
totalCost double
final
totalDiscount double
final
totalDue double?
final
totalMarkup double
final
totalTax double
final
totalValue double
final
transactionDate String
final
transactionID String
final
transactionTime String
final
vAT String
final
website String
final
whatsapp String
final
withdrawalAmount double?
final

Methods

copyWith({String? transactionID, String? id, String? customerId, String? customerName, String? customerEmail, String? customerMobile, bool? displayCustomer, bool? displaySeller, bool? displayAddress, bool? displayBusinessMobile, String? ticketId, String? ticketName, String? sellerId, String? sellerName, String? currencyCode, String? countryCode, String? deviceId, bool? taxInclusive, double? totalValue, double? totalCost, double? totalMarkup, double? totalDiscount, double? totalTax, double? amountTendered, double? amountChange, String? transactionDate, String? transactionTime, String? businessName, PrintAddressInterface? address, String? vAT, String? tell, String? checkoutMessage, String? taxCode, double? taxValue, List<InventoryInterface>? items, String? header, String? footer, String? instagram, String? website, String? whatsapp, Uint8List? image, double? cashbackAmount, double? tipAmount, double? totalDue, double? withdrawalAmount, String? paymentType}) PrinterRequestInterface
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited