ScanResultInterface class
Constructors
- ScanResultInterface({String resultString = '', String resultFormat = ''})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- resultFormat → String
-
final
- resultString → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited